JsDoc: SimileAjax.XmlHttp

Library: SimileAjax.XmlHttp
Overview
XmlHttp utility functions
Constructors
Functions
SimileAjax.XmlHttp._onReadyStateChange(xmlhttp, fError, fDone)
Callback for XMLHttp onRequestStateChange.
parameters

| xmlhttp |
| fError |
| fDone |

SimileAjax.XmlHttp._createRequest()
Creates an XMLHttpRequest object. On the first run, this function creates a platform-specific function for instantiating an XMLHttpRequest object and then replaces itself with that function.
SimileAjax.XmlHttp.get(fError, fDone)
Performs an asynchronous HTTP GET.
parameters

Function | fError | a function of the form function(statusText, statusCode, xmlhttp)
Function | fDone | a function of the form function(xmlhttp)

SimileAjax.XmlHttp.post(fError, fDone)
Performs an asynchronous HTTP POST.
parameters

Function | fError | a function of the form function(statusText, statusCode, xmlhttp)
Function | fDone | a function of the form function(xmlhttp)

Objects
Generated by JsDoc Toolkit on Tue, 07 Aug 2007 20:53:48 GMT